@@ -98,9 +98,9 @@ class ForecastServiceClient:
             "METRICS",
         ],
         DatasetType: Literal["TARGET_TIME_SERIES", "RELATED_TIME_SERIES", "ITEM_METADATA"],
-        Schema: SchemaTypeDef,
+        Schema: "SchemaTypeDef",
         DataFrequency: str = None,
-        EncryptionConfig: EncryptionConfigTypeDef = None,
+        EncryptionConfig: "EncryptionConfigTypeDef" = None,
     ) -> CreateDatasetResponseTypeDef:
         """
         [Client.create_dataset documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.create_dataset)
@@ -128,7 +128,7 @@ class ForecastServiceClient:
         self,
         DatasetImportJobName: str,
         DatasetArn: str,
-        DataSource: DataSourceTypeDef,
+        DataSource: "DataSourceTypeDef",
         TimestampFormat: str = None,
     ) -> CreateDatasetImportJobResponseTypeDef:
         """
@@ -143,7 +143,7 @@ class ForecastServiceClient:
         """
 
     def create_forecast_export_job(
-        self, ForecastExportJobName: str, ForecastArn: str, Destination: DataDestinationTypeDef
+        self, ForecastExportJobName: str, ForecastArn: str, Destination: "DataDestinationTypeDef"
     ) -> CreateForecastExportJobResponseTypeDef:
         """
         [Client.create_forecast_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.create_forecast_export_job)
@@ -153,15 +153,15 @@ class ForecastServiceClient:
         self,
         PredictorName: str,
         ForecastHorizon: int,
-        InputDataConfig: InputDataConfigTypeDef,
-        FeaturizationConfig: FeaturizationConfigTypeDef,
+        InputDataConfig: "InputDataConfigTypeDef",
+        FeaturizationConfig: "FeaturizationConfigTypeDef",
         AlgorithmArn: str = None,
         PerformAutoML: bool = None,
         PerformHPO: bool = None,
         TrainingParameters: Dict[str, str] = None,
-        EvaluationParameters: EvaluationParametersTypeDef = None,
-        HPOConfig: HyperParameterTuningJobConfigTypeDef = None,
-        EncryptionConfig: EncryptionConfigTypeDef = None,
+        EvaluationParameters: "EvaluationParametersTypeDef" = None,
+        HPOConfig: "HyperParameterTuningJobConfigTypeDef" = None,
+        EncryptionConfig: "EncryptionConfigTypeDef" = None,
     ) -> CreatePredictorResponseTypeDef:
         """
         [Client.create_predictor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/forecast.html#ForecastService.Client.create_predictor)
