@@ -3,9 +3,9 @@ Main interface for forecast service type definitions.
 
 Usage::
 
-    from mypy_boto3.forecast.type_defs import CreateDatasetGroupResponseTypeDef
+    from mypy_boto3.forecast.type_defs import CategoricalParameterRangeTypeDef
 
-    data: CreateDatasetGroupResponseTypeDef = {...}
+    data: CategoricalParameterRangeTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,60 +22,352 @@ else:
 
 
 __all__ = (
+    "CategoricalParameterRangeTypeDef",
+    "ContinuousParameterRangeTypeDef",
+    "DataDestinationTypeDef",
+    "DataSourceTypeDef",
+    "DatasetGroupSummaryTypeDef",
+    "DatasetImportJobSummaryTypeDef",
+    "DatasetSummaryTypeDef",
+    "EncryptionConfigTypeDef",
+    "EvaluationParametersTypeDef",
+    "EvaluationResultTypeDef",
+    "FeaturizationConfigTypeDef",
+    "FeaturizationMethodTypeDef",
+    "FeaturizationTypeDef",
+    "ForecastExportJobSummaryTypeDef",
+    "ForecastSummaryTypeDef",
+    "HyperParameterTuningJobConfigTypeDef",
+    "InputDataConfigTypeDef",
+    "IntegerParameterRangeTypeDef",
+    "MetricsTypeDef",
+    "ParameterRangesTypeDef",
+    "PredictorExecutionDetailsTypeDef",
+    "PredictorExecutionTypeDef",
+    "PredictorSummaryTypeDef",
+    "S3ConfigTypeDef",
+    "SchemaAttributeTypeDef",
+    "SchemaTypeDef",
+    "StatisticsTypeDef",
+    "SupplementaryFeatureTypeDef",
+    "TestWindowSummaryTypeDef",
+    "WeightedQuantileLossTypeDef",
+    "WindowSummaryTypeDef",
     "CreateDatasetGroupResponseTypeDef",
     "CreateDatasetImportJobResponseTypeDef",
     "CreateDatasetResponseTypeDef",
     "CreateForecastExportJobResponseTypeDef",
     "CreateForecastResponseTypeDef",
     "CreatePredictorResponseTypeDef",
-    "S3ConfigTypeDef",
-    "DataDestinationTypeDef",
-    "DataSourceTypeDef",
     "DescribeDatasetGroupResponseTypeDef",
-    "StatisticsTypeDef",
     "DescribeDatasetImportJobResponseTypeDef",
-    "EncryptionConfigTypeDef",
-    "SchemaAttributeTypeDef",
-    "SchemaTypeDef",
     "DescribeDatasetResponseTypeDef",
     "DescribeForecastExportJobResponseTypeDef",
     "DescribeForecastResponseTypeDef",
-    "EvaluationParametersTypeDef",
-    "FeaturizationMethodTypeDef",
-    "FeaturizationTypeDef",
-    "FeaturizationConfigTypeDef",
-    "CategoricalParameterRangeTypeDef",
-    "ContinuousParameterRangeTypeDef",
-    "IntegerParameterRangeTypeDef",
-    "ParameterRangesTypeDef",
-    "HyperParameterTuningJobConfigTypeDef",
-    "SupplementaryFeatureTypeDef",
-    "InputDataConfigTypeDef",
-    "TestWindowSummaryTypeDef",
-    "PredictorExecutionTypeDef",
-    "PredictorExecutionDetailsTypeDef",
     "DescribePredictorResponseTypeDef",
     "FilterTypeDef",
-    "WeightedQuantileLossTypeDef",
-    "MetricsTypeDef",
-    "WindowSummaryTypeDef",
-    "EvaluationResultTypeDef",
     "GetAccuracyMetricsResponseTypeDef",
-    "DatasetGroupSummaryTypeDef",
     "ListDatasetGroupsResponseTypeDef",
-    "DatasetImportJobSummaryTypeDef",
     "ListDatasetImportJobsResponseTypeDef",
-    "DatasetSummaryTypeDef",
     "ListDatasetsResponseTypeDef",
-    "ForecastExportJobSummaryTypeDef",
     "ListForecastExportJobsResponseTypeDef",
-    "ForecastSummaryTypeDef",
     "ListForecastsResponseTypeDef",
-    "PredictorSummaryTypeDef",
     "ListPredictorsResponseTypeDef",
     "PaginatorConfigTypeDef",
 )
 
+CategoricalParameterRangeTypeDef = TypedDict(
+    "CategoricalParameterRangeTypeDef", {"Name": str, "Values": List[str]}
+)
+
+_RequiredContinuousParameterRangeTypeDef = TypedDict(
+    "_RequiredContinuousParameterRangeTypeDef", {"Name": str, "MaxValue": float, "MinValue": float}
+)
+_OptionalContinuousParameterRangeTypeDef = TypedDict(
+    "_OptionalContinuousParameterRangeTypeDef",
+    {"ScalingType": Literal["Auto", "Linear", "Logarithmic", "ReverseLogarithmic"]},
+    total=False,
+)
+
+
+class ContinuousParameterRangeTypeDef(
+    _RequiredContinuousParameterRangeTypeDef, _OptionalContinuousParameterRangeTypeDef
+):
+    pass
+
+
+DataDestinationTypeDef = TypedDict("DataDestinationTypeDef", {"S3Config": "S3ConfigTypeDef"})
+
+DataSourceTypeDef = TypedDict("DataSourceTypeDef", {"S3Config": "S3ConfigTypeDef"})
+
+DatasetGroupSummaryTypeDef = TypedDict(
+    "DatasetGroupSummaryTypeDef",
+    {
+        "DatasetGroupArn": str,
+        "DatasetGroupName": str,
+        "CreationTime": datetime,
+        "LastModificationTime": datetime,
+    },
+    total=False,
+)
+
+DatasetImportJobSummaryTypeDef = TypedDict(
+    "DatasetImportJobSummaryTypeDef",
+    {
+        "DatasetImportJobArn": str,
+        "DatasetImportJobName": str,
+        "DataSource": "DataSourceTypeDef",
+        "Status": str,
+        "Message": str,
+        "CreationTime": datetime,
+        "LastModificationTime": datetime,
+    },
+    total=False,
+)
+
+DatasetSummaryTypeDef = TypedDict(
+    "DatasetSummaryTypeDef",
+    {
+        "DatasetArn": str,
+        "DatasetName": str,
+        "DatasetType": Literal["TARGET_TIME_SERIES", "RELATED_TIME_SERIES", "ITEM_METADATA"],
+        "Domain": Literal[
+            "RETAIL",
+            "CUSTOM",
+            "INVENTORY_PLANNING",
+            "EC2_CAPACITY",
+            "WORK_FORCE",
+            "WEB_TRAFFIC",
+            "METRICS",
+        ],
+        "CreationTime": datetime,
+        "LastModificationTime": datetime,
+    },
+    total=False,
+)
+
+EncryptionConfigTypeDef = TypedDict("EncryptionConfigTypeDef", {"RoleArn": str, "KMSKeyArn": str})
+
+EvaluationParametersTypeDef = TypedDict(
+    "EvaluationParametersTypeDef",
+    {"NumberOfBacktestWindows": int, "BackTestWindowOffset": int},
+    total=False,
+)
+
+EvaluationResultTypeDef = TypedDict(
+    "EvaluationResultTypeDef",
+    {"AlgorithmArn": str, "TestWindows": List["WindowSummaryTypeDef"]},
+    total=False,
+)
+
+_RequiredFeaturizationConfigTypeDef = TypedDict(
+    "_RequiredFeaturizationConfigTypeDef", {"ForecastFrequency": str}
+)
+_OptionalFeaturizationConfigTypeDef = TypedDict(
+    "_OptionalFeaturizationConfigTypeDef",
+    {"ForecastDimensions": List[str], "Featurizations": List["FeaturizationTypeDef"]},
+    total=False,
+)
+
+
+class FeaturizationConfigTypeDef(
+    _RequiredFeaturizationConfigTypeDef, _OptionalFeaturizationConfigTypeDef
+):
+    pass
+
+
+_RequiredFeaturizationMethodTypeDef = TypedDict(
+    "_RequiredFeaturizationMethodTypeDef", {"FeaturizationMethodName": Literal["filling"]}
+)
+_OptionalFeaturizationMethodTypeDef = TypedDict(
+    "_OptionalFeaturizationMethodTypeDef",
+    {"FeaturizationMethodParameters": Dict[str, str]},
+    total=False,
+)
+
+
+class FeaturizationMethodTypeDef(
+    _RequiredFeaturizationMethodTypeDef, _OptionalFeaturizationMethodTypeDef
+):
+    pass
+
+
+_RequiredFeaturizationTypeDef = TypedDict("_RequiredFeaturizationTypeDef", {"AttributeName": str})
+_OptionalFeaturizationTypeDef = TypedDict(
+    "_OptionalFeaturizationTypeDef",
+    {"FeaturizationPipeline": List["FeaturizationMethodTypeDef"]},
+    total=False,
+)
+
+
+class FeaturizationTypeDef(_RequiredFeaturizationTypeDef, _OptionalFeaturizationTypeDef):
+    pass
+
+
+ForecastExportJobSummaryTypeDef = TypedDict(
+    "ForecastExportJobSummaryTypeDef",
+    {
+        "ForecastExportJobArn": str,
+        "ForecastExportJobName": str,
+        "Destination": "DataDestinationTypeDef",
+        "Status": str,
+        "Message": str,
+        "CreationTime": datetime,
+        "LastModificationTime": datetime,
+    },
+    total=False,
+)
+
+ForecastSummaryTypeDef = TypedDict(
+    "ForecastSummaryTypeDef",
+    {
+        "ForecastArn": str,
+        "ForecastName": str,
+        "PredictorArn": str,
+        "DatasetGroupArn": str,
+        "Status": str,
+        "Message": str,
+        "CreationTime": datetime,
+        "LastModificationTime": datetime,
+    },
+    total=False,
+)
+
+HyperParameterTuningJobConfigTypeDef = TypedDict(
+    "HyperParameterTuningJobConfigTypeDef",
+    {"ParameterRanges": "ParameterRangesTypeDef"},
+    total=False,
+)
+
+_RequiredInputDataConfigTypeDef = TypedDict(
+    "_RequiredInputDataConfigTypeDef", {"DatasetGroupArn": str}
+)
+_OptionalInputDataConfigTypeDef = TypedDict(
+    "_OptionalInputDataConfigTypeDef",
+    {"SupplementaryFeatures": List["SupplementaryFeatureTypeDef"]},
+    total=False,
+)
+
+
+class InputDataConfigTypeDef(_RequiredInputDataConfigTypeDef, _OptionalInputDataConfigTypeDef):
+    pass
+
+
+_RequiredIntegerParameterRangeTypeDef = TypedDict(
+    "_RequiredIntegerParameterRangeTypeDef", {"Name": str, "MaxValue": int, "MinValue": int}
+)
+_OptionalIntegerParameterRangeTypeDef = TypedDict(
+    "_OptionalIntegerParameterRangeTypeDef",
+    {"ScalingType": Literal["Auto", "Linear", "Logarithmic", "ReverseLogarithmic"]},
+    total=False,
+)
+
+
+class IntegerParameterRangeTypeDef(
+    _RequiredIntegerParameterRangeTypeDef, _OptionalIntegerParameterRangeTypeDef
+):
+    pass
+
+
+MetricsTypeDef = TypedDict(
+    "MetricsTypeDef",
+    {"RMSE": float, "WeightedQuantileLosses": List["WeightedQuantileLossTypeDef"]},
+    total=False,
+)
+
+ParameterRangesTypeDef = TypedDict(
+    "ParameterRangesTypeDef",
+    {
+        "CategoricalParameterRanges": List["CategoricalParameterRangeTypeDef"],
+        "ContinuousParameterRanges": List["ContinuousParameterRangeTypeDef"],
+        "IntegerParameterRanges": List["IntegerParameterRangeTypeDef"],
+    },
+    total=False,
+)
+
+PredictorExecutionDetailsTypeDef = TypedDict(
+    "PredictorExecutionDetailsTypeDef",
+    {"PredictorExecutions": List["PredictorExecutionTypeDef"]},
+    total=False,
+)
+
+PredictorExecutionTypeDef = TypedDict(
+    "PredictorExecutionTypeDef",
+    {"AlgorithmArn": str, "TestWindows": List["TestWindowSummaryTypeDef"]},
+    total=False,
+)
+
+PredictorSummaryTypeDef = TypedDict(
+    "PredictorSummaryTypeDef",
+    {
+        "PredictorArn": str,
+        "PredictorName": str,
+        "DatasetGroupArn": str,
+        "Status": str,
+        "Message": str,
+        "CreationTime": datetime,
+        "LastModificationTime": datetime,
+    },
+    total=False,
+)
+
+_RequiredS3ConfigTypeDef = TypedDict("_RequiredS3ConfigTypeDef", {"Path": str, "RoleArn": str})
+_OptionalS3ConfigTypeDef = TypedDict("_OptionalS3ConfigTypeDef", {"KMSKeyArn": str}, total=False)
+
+
+class S3ConfigTypeDef(_RequiredS3ConfigTypeDef, _OptionalS3ConfigTypeDef):
+    pass
+
+
+SchemaAttributeTypeDef = TypedDict(
+    "SchemaAttributeTypeDef",
+    {"AttributeName": str, "AttributeType": Literal["string", "integer", "float", "timestamp"]},
+    total=False,
+)
+
+SchemaTypeDef = TypedDict(
+    "SchemaTypeDef", {"Attributes": List["SchemaAttributeTypeDef"]}, total=False
+)
+
+StatisticsTypeDef = TypedDict(
+    "StatisticsTypeDef",
+    {
+        "Count": int,
+        "CountDistinct": int,
+        "CountNull": int,
+        "CountNan": int,
+        "Min": str,
+        "Max": str,
+        "Avg": float,
+        "Stddev": float,
+    },
+    total=False,
+)
+
+SupplementaryFeatureTypeDef = TypedDict("SupplementaryFeatureTypeDef", {"Name": str, "Value": str})
+
+TestWindowSummaryTypeDef = TypedDict(
+    "TestWindowSummaryTypeDef",
+    {"TestWindowStart": datetime, "TestWindowEnd": datetime, "Status": str, "Message": str},
+    total=False,
+)
+
+WeightedQuantileLossTypeDef = TypedDict(
+    "WeightedQuantileLossTypeDef", {"Quantile": float, "LossValue": float}, total=False
+)
+
+WindowSummaryTypeDef = TypedDict(
+    "WindowSummaryTypeDef",
+    {
+        "TestWindowStart": datetime,
+        "TestWindowEnd": datetime,
+        "ItemCount": int,
+        "EvaluationType": Literal["SUMMARY", "COMPUTED"],
+        "Metrics": "MetricsTypeDef",
+    },
+    total=False,
+)
+
 CreateDatasetGroupResponseTypeDef = TypedDict(
     "CreateDatasetGroupResponseTypeDef", {"DatasetGroupArn": str}, total=False
 )
@@ -100,18 +392,6 @@ CreatePredictorResponseTypeDef = TypedDict(
     "CreatePredictorResponseTypeDef", {"PredictorArn": str}, total=False
 )
 
-_RequiredS3ConfigTypeDef = TypedDict("_RequiredS3ConfigTypeDef", {"Path": str, "RoleArn": str})
-_OptionalS3ConfigTypeDef = TypedDict("_OptionalS3ConfigTypeDef", {"KMSKeyArn": str}, total=False)
-
-
-class S3ConfigTypeDef(_RequiredS3ConfigTypeDef, _OptionalS3ConfigTypeDef):
-    pass
-
-
-DataDestinationTypeDef = TypedDict("DataDestinationTypeDef", {"S3Config": S3ConfigTypeDef})
-
-DataSourceTypeDef = TypedDict("DataSourceTypeDef", {"S3Config": S3ConfigTypeDef})
-
 DescribeDatasetGroupResponseTypeDef = TypedDict(
     "DescribeDatasetGroupResponseTypeDef",
     {
@@ -134,21 +414,6 @@ DescribeDatasetGroupResponseTypeDef = TypedDict(
     total=False,
 )
 
-StatisticsTypeDef = TypedDict(
-    "StatisticsTypeDef",
-    {
-        "Count": int,
-        "CountDistinct": int,
-        "CountNull": int,
-        "CountNan": int,
-        "Min": str,
-        "Max": str,
-        "Avg": float,
-        "Stddev": float,
-    },
-    total=False,
-)
-
 DescribeDatasetImportJobResponseTypeDef = TypedDict(
     "DescribeDatasetImportJobResponseTypeDef",
     {
@@ -156,8 +421,8 @@ DescribeDatasetImportJobResponseTypeDef = TypedDict(
         "DatasetImportJobArn": str,
         "DatasetArn": str,
         "TimestampFormat": str,
-        "DataSource": DataSourceTypeDef,
-        "FieldStatistics": Dict[str, StatisticsTypeDef],
+        "DataSource": "DataSourceTypeDef",
+        "FieldStatistics": Dict[str, "StatisticsTypeDef"],
         "DataSize": float,
         "Status": str,
         "Message": str,
@@ -167,18 +432,6 @@ DescribeDatasetImportJobResponseTypeDef = TypedDict(
     total=False,
 )
 
-EncryptionConfigTypeDef = TypedDict("EncryptionConfigTypeDef", {"RoleArn": str, "KMSKeyArn": str})
-
-SchemaAttributeTypeDef = TypedDict(
-    "SchemaAttributeTypeDef",
-    {"AttributeName": str, "AttributeType": Literal["string", "integer", "float", "timestamp"]},
-    total=False,
-)
-
-SchemaTypeDef = TypedDict(
-    "SchemaTypeDef", {"Attributes": List[SchemaAttributeTypeDef]}, total=False
-)
-
 DescribeDatasetResponseTypeDef = TypedDict(
     "DescribeDatasetResponseTypeDef",
     {
@@ -195,8 +448,8 @@ DescribeDatasetResponseTypeDef = TypedDict(
         ],
         "DatasetType": Literal["TARGET_TIME_SERIES", "RELATED_TIME_SERIES", "ITEM_METADATA"],
         "DataFrequency": str,
-        "Schema": SchemaTypeDef,
-        "EncryptionConfig": EncryptionConfigTypeDef,
+        "Schema": "SchemaTypeDef",
+        "EncryptionConfig": "EncryptionConfigTypeDef",
         "Status": str,
         "CreationTime": datetime,
         "LastModificationTime": datetime,
@@ -210,7 +463,7 @@ DescribeForecastExportJobResponseTypeDef = TypedDict(
         "ForecastExportJobArn": str,
         "ForecastExportJobName": str,
         "ForecastArn": str,
-        "Destination": DataDestinationTypeDef,
+        "Destination": "DataDestinationTypeDef",
         "Message": str,
         "Status": str,
         "CreationTime": datetime,
@@ -235,140 +488,6 @@ DescribeForecastResponseTypeDef = TypedDict(
     total=False,
 )
 
-EvaluationParametersTypeDef = TypedDict(
-    "EvaluationParametersTypeDef",
-    {"NumberOfBacktestWindows": int, "BackTestWindowOffset": int},
-    total=False,
-)
-
-_RequiredFeaturizationMethodTypeDef = TypedDict(
-    "_RequiredFeaturizationMethodTypeDef", {"FeaturizationMethodName": Literal["filling"]}
-)
-_OptionalFeaturizationMethodTypeDef = TypedDict(
-    "_OptionalFeaturizationMethodTypeDef",
-    {"FeaturizationMethodParameters": Dict[str, str]},
-    total=False,
-)
-
-
-class FeaturizationMethodTypeDef(
-    _RequiredFeaturizationMethodTypeDef, _OptionalFeaturizationMethodTypeDef
-):
-    pass
-
-
-_RequiredFeaturizationTypeDef = TypedDict("_RequiredFeaturizationTypeDef", {"AttributeName": str})
-_OptionalFeaturizationTypeDef = TypedDict(
-    "_OptionalFeaturizationTypeDef",
-    {"FeaturizationPipeline": List[FeaturizationMethodTypeDef]},
-    total=False,
-)
-
-
-class FeaturizationTypeDef(_RequiredFeaturizationTypeDef, _OptionalFeaturizationTypeDef):
-    pass
-
-
-_RequiredFeaturizationConfigTypeDef = TypedDict(
-    "_RequiredFeaturizationConfigTypeDef", {"ForecastFrequency": str}
-)
-_OptionalFeaturizationConfigTypeDef = TypedDict(
-    "_OptionalFeaturizationConfigTypeDef",
-    {"ForecastDimensions": List[str], "Featurizations": List[FeaturizationTypeDef]},
-    total=False,
-)
-
-
-class FeaturizationConfigTypeDef(
-    _RequiredFeaturizationConfigTypeDef, _OptionalFeaturizationConfigTypeDef
-):
-    pass
-
-
-CategoricalParameterRangeTypeDef = TypedDict(
-    "CategoricalParameterRangeTypeDef", {"Name": str, "Values": List[str]}
-)
-
-_RequiredContinuousParameterRangeTypeDef = TypedDict(
-    "_RequiredContinuousParameterRangeTypeDef", {"Name": str, "MaxValue": float, "MinValue": float}
-)
-_OptionalContinuousParameterRangeTypeDef = TypedDict(
-    "_OptionalContinuousParameterRangeTypeDef",
-    {"ScalingType": Literal["Auto", "Linear", "Logarithmic", "ReverseLogarithmic"]},
-    total=False,
-)
-
-
-class ContinuousParameterRangeTypeDef(
-    _RequiredContinuousParameterRangeTypeDef, _OptionalContinuousParameterRangeTypeDef
-):
-    pass
-
-
-_RequiredIntegerParameterRangeTypeDef = TypedDict(
-    "_RequiredIntegerParameterRangeTypeDef", {"Name": str, "MaxValue": int, "MinValue": int}
-)
-_OptionalIntegerParameterRangeTypeDef = TypedDict(
-    "_OptionalIntegerParameterRangeTypeDef",
-    {"ScalingType": Literal["Auto", "Linear", "Logarithmic", "ReverseLogarithmic"]},
-    total=False,
-)
-
-
-class IntegerParameterRangeTypeDef(
-    _RequiredIntegerParameterRangeTypeDef, _OptionalIntegerParameterRangeTypeDef
-):
-    pass
-
-
-ParameterRangesTypeDef = TypedDict(
-    "ParameterRangesTypeDef",
-    {
-        "CategoricalParameterRanges": List[CategoricalParameterRangeTypeDef],
-        "ContinuousParameterRanges": List[ContinuousParameterRangeTypeDef],
-        "IntegerParameterRanges": List[IntegerParameterRangeTypeDef],
-    },
-    total=False,
-)
-
-HyperParameterTuningJobConfigTypeDef = TypedDict(
-    "HyperParameterTuningJobConfigTypeDef", {"ParameterRanges": ParameterRangesTypeDef}, total=False
-)
-
-SupplementaryFeatureTypeDef = TypedDict("SupplementaryFeatureTypeDef", {"Name": str, "Value": str})
-
-_RequiredInputDataConfigTypeDef = TypedDict(
-    "_RequiredInputDataConfigTypeDef", {"DatasetGroupArn": str}
-)
-_OptionalInputDataConfigTypeDef = TypedDict(
-    "_OptionalInputDataConfigTypeDef",
-    {"SupplementaryFeatures": List[SupplementaryFeatureTypeDef]},
-    total=False,
-)
-
-
-class InputDataConfigTypeDef(_RequiredInputDataConfigTypeDef, _OptionalInputDataConfigTypeDef):
-    pass
-
-
-TestWindowSummaryTypeDef = TypedDict(
-    "TestWindowSummaryTypeDef",
-    {"TestWindowStart": datetime, "TestWindowEnd": datetime, "Status": str, "Message": str},
-    total=False,
-)
-
-PredictorExecutionTypeDef = TypedDict(
-    "PredictorExecutionTypeDef",
-    {"AlgorithmArn": str, "TestWindows": List[TestWindowSummaryTypeDef]},
-    total=False,
-)
-
-PredictorExecutionDetailsTypeDef = TypedDict(
-    "PredictorExecutionDetailsTypeDef",
-    {"PredictorExecutions": List[PredictorExecutionTypeDef]},
-    total=False,
-)
-
 DescribePredictorResponseTypeDef = TypedDict(
     "DescribePredictorResponseTypeDef",
     {
@@ -379,12 +498,12 @@ DescribePredictorResponseTypeDef = TypedDict(
         "PerformAutoML": bool,
         "PerformHPO": bool,
         "TrainingParameters": Dict[str, str],
-        "EvaluationParameters": EvaluationParametersTypeDef,
-        "HPOConfig": HyperParameterTuningJobConfigTypeDef,
-        "InputDataConfig": InputDataConfigTypeDef,
-        "FeaturizationConfig": FeaturizationConfigTypeDef,
-        "EncryptionConfig": EncryptionConfigTypeDef,
-        "PredictorExecutionDetails": PredictorExecutionDetailsTypeDef,
+        "EvaluationParameters": "EvaluationParametersTypeDef",
+        "HPOConfig": "HyperParameterTuningJobConfigTypeDef",
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "FeaturizationConfig": "FeaturizationConfigTypeDef",
+        "EncryptionConfig": "EncryptionConfigTypeDef",
+        "PredictorExecutionDetails": "PredictorExecutionDetailsTypeDef",
         "DatasetImportJobArns": List[str],
         "AutoMLAlgorithmArns": List[str],
         "Status": str,
@@ -399,162 +518,45 @@ FilterTypeDef = TypedDict(
     "FilterTypeDef", {"Key": str, "Value": str, "Condition": Literal["IS", "IS_NOT"]}
 )
 
-WeightedQuantileLossTypeDef = TypedDict(
-    "WeightedQuantileLossTypeDef", {"Quantile": float, "LossValue": float}, total=False
-)
-
-MetricsTypeDef = TypedDict(
-    "MetricsTypeDef",
-    {"RMSE": float, "WeightedQuantileLosses": List[WeightedQuantileLossTypeDef]},
-    total=False,
-)
-
-WindowSummaryTypeDef = TypedDict(
-    "WindowSummaryTypeDef",
-    {
-        "TestWindowStart": datetime,
-        "TestWindowEnd": datetime,
-        "ItemCount": int,
-        "EvaluationType": Literal["SUMMARY", "COMPUTED"],
-        "Metrics": MetricsTypeDef,
-    },
-    total=False,
-)
-
-EvaluationResultTypeDef = TypedDict(
-    "EvaluationResultTypeDef",
-    {"AlgorithmArn": str, "TestWindows": List[WindowSummaryTypeDef]},
-    total=False,
-)
-
 GetAccuracyMetricsResponseTypeDef = TypedDict(
     "GetAccuracyMetricsResponseTypeDef",
-    {"PredictorEvaluationResults": List[EvaluationResultTypeDef]},
-    total=False,
-)
-
-DatasetGroupSummaryTypeDef = TypedDict(
-    "DatasetGroupSummaryTypeDef",
-    {
-        "DatasetGroupArn": str,
-        "DatasetGroupName": str,
-        "CreationTime": datetime,
-        "LastModificationTime": datetime,
-    },
+    {"PredictorEvaluationResults": List["EvaluationResultTypeDef"]},
     total=False,
 )
 
 ListDatasetGroupsResponseTypeDef = TypedDict(
     "ListDatasetGroupsResponseTypeDef",
-    {"DatasetGroups": List[DatasetGroupSummaryTypeDef], "NextToken": str},
-    total=False,
-)
-
-DatasetImportJobSummaryTypeDef = TypedDict(
-    "DatasetImportJobSummaryTypeDef",
-    {
-        "DatasetImportJobArn": str,
-        "DatasetImportJobName": str,
-        "DataSource": DataSourceTypeDef,
-        "Status": str,
-        "Message": str,
-        "CreationTime": datetime,
-        "LastModificationTime": datetime,
-    },
+    {"DatasetGroups": List["DatasetGroupSummaryTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListDatasetImportJobsResponseTypeDef = TypedDict(
     "ListDatasetImportJobsResponseTypeDef",
-    {"DatasetImportJobs": List[DatasetImportJobSummaryTypeDef], "NextToken": str},
-    total=False,
-)
-
-DatasetSummaryTypeDef = TypedDict(
-    "DatasetSummaryTypeDef",
-    {
-        "DatasetArn": str,
-        "DatasetName": str,
-        "DatasetType": Literal["TARGET_TIME_SERIES", "RELATED_TIME_SERIES", "ITEM_METADATA"],
-        "Domain": Literal[
-            "RETAIL",
-            "CUSTOM",
-            "INVENTORY_PLANNING",
-            "EC2_CAPACITY",
-            "WORK_FORCE",
-            "WEB_TRAFFIC",
-            "METRICS",
-        ],
-        "CreationTime": datetime,
-        "LastModificationTime": datetime,
-    },
+    {"DatasetImportJobs": List["DatasetImportJobSummaryTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListDatasetsResponseTypeDef = TypedDict(
     "ListDatasetsResponseTypeDef",
-    {"Datasets": List[DatasetSummaryTypeDef], "NextToken": str},
-    total=False,
-)
-
-ForecastExportJobSummaryTypeDef = TypedDict(
-    "ForecastExportJobSummaryTypeDef",
-    {
-        "ForecastExportJobArn": str,
-        "ForecastExportJobName": str,
-        "Destination": DataDestinationTypeDef,
-        "Status": str,
-        "Message": str,
-        "CreationTime": datetime,
-        "LastModificationTime": datetime,
-    },
+    {"Datasets": List["DatasetSummaryTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListForecastExportJobsResponseTypeDef = TypedDict(
     "ListForecastExportJobsResponseTypeDef",
-    {"ForecastExportJobs": List[ForecastExportJobSummaryTypeDef], "NextToken": str},
-    total=False,
-)
-
-ForecastSummaryTypeDef = TypedDict(
-    "ForecastSummaryTypeDef",
-    {
-        "ForecastArn": str,
-        "ForecastName": str,
-        "PredictorArn": str,
-        "DatasetGroupArn": str,
-        "Status": str,
-        "Message": str,
-        "CreationTime": datetime,
-        "LastModificationTime": datetime,
-    },
+    {"ForecastExportJobs": List["ForecastExportJobSummaryTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListForecastsResponseTypeDef = TypedDict(
     "ListForecastsResponseTypeDef",
-    {"Forecasts": List[ForecastSummaryTypeDef], "NextToken": str},
-    total=False,
-)
-
-PredictorSummaryTypeDef = TypedDict(
-    "PredictorSummaryTypeDef",
-    {
-        "PredictorArn": str,
-        "PredictorName": str,
-        "DatasetGroupArn": str,
-        "Status": str,
-        "Message": str,
-        "CreationTime": datetime,
-        "LastModificationTime": datetime,
-    },
+    {"Forecasts": List["ForecastSummaryTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListPredictorsResponseTypeDef = TypedDict(
     "ListPredictorsResponseTypeDef",
-    {"Predictors": List[PredictorSummaryTypeDef], "NextToken": str},
+    {"Predictors": List["PredictorSummaryTypeDef"], "NextToken": str},
     total=False,
 )
 
